@@ -44,11 +44,13 @@ PYBIND11_MODULE(note, m) {
             .def_readwrite("syncopation", &midi_generator::Configuration::syncopation)
             .def_readwrite("density", &midi_generator::Configuration::density)
             .def_readwrite("consonance", &midi_generator::Configuration::consonance)
+            .def_readwrite("tempo", &midi_generator::Configuration::tempo)
             .def_readwrite("scale", &midi_generator::Configuration::scale)
             .def_readwrite("bars", &midi_generator::Configuration::bars)
             .def_readwrite("rate", &midi_generator::Configuration::rate)
             .def_readwrite("fitness_method", &midi_generator::Configuration::fitness_method)
             .def_readwrite("compression_method", &midi_generator::Configuration::compression_method)
+            .def_readwrite("syncopation_method", &midi_generator::Configuration::syncopation_algorithm)
             .def_readwrite("pitch_change_rate", &midi_generator::Configuration::pitch_change_rate)
             .def_readwrite("length_change_rate", &midi_generator::Configuration::length_change_rate)
             .def_readwrite("consonance_rate", &midi_generator::Configuration::consonance_rate)
