@@ -1,15 +1,15 @@
 from functools import reduce
 
-from note import Note
+from note import Note, Configuration
 from .types import Gene
 
 
-def individual_to_melody(individual: list[Gene]) -> list[Note]:
+def individual_to_melody(individual: list[Gene], config: Configuration) -> list[Note]:
     notes = []
     start = 0.0
     time = 0.0
     for i, gene in enumerate(individual):
-        time += 0.5
+        time += config.tempo * config.rate / 60 * 2
 
         if gene.remaining_ticks > 1:
             continue
@@ -21,10 +21,10 @@ def individual_to_melody(individual: list[Gene]) -> list[Note]:
     return notes
 
 
-def melody_to_individual(melody: list[Note]) -> list[Gene]:
-    genes = [Gene(0, 0, 1)] * 32
+def melody_to_individual(melody: list[Note], config: Configuration) -> list[Gene]:
+    genes = [Gene(0, 0, 0)] * config.bars * int(1 / config.rate)
     for note in melody:
-        ticks = int((note.end - note.start) * 2) + 1
+        ticks = int((note.end - note.start) * (1 / config.rate) / config.bars) + 1
         for i in range(ticks, 0, -1):
             genes[int(note.start * 2 + ticks - i - 1)] = Gene(note.pitch, note.velocity, i)
 
